# Nostalgia Chatbot

The chatbot is currently not connected. Please let me know if interested.

It has an NLP layer that makes it super easy for people to sprinkle NLP over their data sources.

![chatbot](https://nostalgia-dev.github.io/assets/images/chatbot1.png)
